Struct osmpbf_parser::proto::osmformat::DenseNodes [−][src]
pub struct DenseNodes {
pub id: Vec<i64>,
pub denseinfo: Option<DenseInfo>,
pub lat: Vec<i64>,
pub lon: Vec<i64>,
pub keys_vals: Vec<i32>,
}Fields
id: Vec<i64>denseinfo: Option<DenseInfo>lat: Vec<i64>lon: Vec<i64>keys_vals: Vec<i32>Trait Implementations
Returns the “default value” for a type. Read more
Constructs an instance of Self by reading from the given bytes
via the given reader. Read more
Writes Self into W writer
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.