Struct osmpbf_parser::proto::osmformat::HeaderBlock [−][src]
pub struct HeaderBlock {
pub bbox: Option<HeaderBBox>,
pub required_features: Vec<String>,
pub optional_features: Vec<String>,
pub writingprogram: Option<String>,
pub source: Option<String>,
pub osmosis_replication_timestamp: Option<i64>,
pub osmosis_replication_sequence_number: Option<i64>,
pub osmosis_replication_base_url: Option<String>,
}Fields
bbox: Option<HeaderBBox>required_features: Vec<String>optional_features: Vec<String>writingprogram: Option<String>source: Option<String>osmosis_replication_timestamp: Option<i64>osmosis_replication_sequence_number: Option<i64>osmosis_replication_base_url: Option<String>Trait Implementations
Returns the “default value” for a type. Read more
Constructs an instance of Self by reading from the given bytes
via the given reader. Read more
Writes Self into W writer
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.