Struct osmpbf_parser::proto::osmformat::PrimitiveGroup [−][src]
pub struct PrimitiveGroup {
pub nodes: Vec<Node>,
pub dense: Option<DenseNodes>,
pub ways: Vec<Way>,
pub relations: Vec<Relation>,
pub changesets: Vec<ChangeSet>,
}Fields
nodes: Vec<Node>dense: Option<DenseNodes>ways: Vec<Way>relations: Vec<Relation>changesets: Vec<ChangeSet>Trait Implementations
Returns the “default value” for a type. Read more
Constructs an instance of Self by reading from the given bytes
via the given reader. Read more
Writes Self into W writer
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.