Struct osmpbf_parser::proto::osmformat::StringTable [−][src]
Fields
s: Vec<Vec<u8>>Trait Implementations
Returns the “default value” for a type. Read more
Constructs an instance of Self by reading from the given bytes
via the given reader. Read more
Writes Self into W writer
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.